Pulsante 'Inserisci tabella'

Pulsante 'Inserisci tabella' | TOC

Il pulsante 'Inserisci tabella' apre la finestra mostrata qui sotto. Questa azione permette di creare tabelle.
Descrizione dei parametri:

Colonne | Numero di colonne nella nuova tabella.
Righe | Numero di righe nella nuova tabella.
Cellpadding | Spazio tra il bordo di una cella e il suo contenuto.
Cellspacing | Spazio tra le celle della tabella.
Allineamento | Allineamento della tabella.
Bordo | Spessore del bordo della tabella.
Larghezza | Larghezza, in pixel, della tabella.
Altezza | Altezza, in pixel, della tabella.
Classe | Stile o classe CSS della tabella.

Vai a: Tavola dei contenuti | Su